@@ -64,6 +64,22 @@ sub get_occurence
     return defined($age) ? ($age - 1) : undef;
 }
 
+sub get_subject
+{
+    my $this = shift;
+
+    my $name = $this->get_name();
+    my $age  = $this->get_occurence();
+    my $when = $this->{"WHEN"};
+
+    if ($age and $when eq "today") {
+        return "$name is now $age";
+    }
+    else {
+        return "${name}'s birthday";
+    }
+}
+
 sub get_message_body
 {
     my $this = shift;
@@ -77,13 +93,10 @@ sub get_message_body
     my $age   = $this->get_occurence();
     my $when  = $this->{"WHEN"};
     
-    my $subject = ($age and $when eq "today") ? "$name is now $age" : "${name}'s birthday";
     my $age_string = $age ? "turning $age" : "getting one year older";
     my $email_message = $email ? "\n\nYou can reach $name at $email." : "";
 
     my $message = <<MESSAGEEND;
-Subject: $subject
-
 Hi $first_name,
 
 I just want to remind you that $name is $age_string $when.$email_message
