@@ -2,7 +2,7 @@
 #
 # Email-Reminder is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; either version 2 of the
+# published by the Free Software Foundation; either version 3 of the
 # License, or (at your option) any later version.
 #
 # Email-Reminder is distributed in the hope that it will be useful,
@@ -31,7 +31,11 @@ use EmailReminder::AnniversaryEvent;
 use EmailReminder::AnniversaryStore;
 use EmailReminder::BirthdayEvent;
 use EmailReminder::BirthdayStore;
+use EmailReminder::MonthlyEvent;
+use EmailReminder::MonthlyStore;
 use EmailReminder::Utils;
+use EmailReminder::WeeklyEvent;
+use EmailReminder::WeeklyStore;
 use EmailReminder::YearlyEvent;
 use EmailReminder::YearlyStore;
 
@@ -66,7 +70,7 @@ sub new
 
 sub process_file
 {
-    my ($this, $create) = @_;
+    my ($this, $create, $readonly) = @_;
 
     # Make sure the config file exists and is readable
     my $filename = $this->{LOADED_FILENAME};
@@ -74,7 +78,7 @@ sub process_file
     {
         if ($create)
         {
-            open CFG, ">$filename";
+            open CFG, '>:utf8', "$filename";
             print CFG '<?xml version="1.0"?><email-reminder_user/>';
             close CFG;
         }
@@ -89,7 +93,10 @@ sub process_file
         warn "File '$filename' exists but is not readable.\n";
         exit(1);
     }
-    warn "WARNING: File '$filename' is not writable, your changes will be lost!\n" unless -w $filename;
+    if (!$readonly and !(-w $filename))
+    {
+        warn "WARNING: File '$filename' is not writable, your changes will be lost!\n";
+    }
 
     # Start parsing the XML file
     my $parser = XML::DOM::Parser->new();
@@ -157,6 +164,12 @@ sub create_event
     elsif ($type eq EmailReminder::AnniversaryEvent->get_type()) {
         $event = EmailReminder::AnniversaryEvent->new($event_node, $id);
     } 
+    elsif ($type eq EmailReminder::MonthlyEvent->get_type()) {
+        $event = EmailReminder::MonthlyEvent->new($event_node, $id);
+    }
+    elsif ($type eq EmailReminder::WeeklyEvent->get_type()) {
+        $event = EmailReminder::WeeklyEvent->new($event_node, $id);
+    }
     elsif ($type eq EmailReminder::YearlyEvent->get_type()) {
         $event = EmailReminder::YearlyEvent->new($event_node, $id);
     }
@@ -174,7 +187,7 @@ sub save
     print $xml_document if $verbose;
 
     # Overwrite the file
-    if (open OUT, ">$filename")
+    if (open OUT, '>:utf8', "$filename")
     {
         print OUT $xml_document;
         print "Sucessfully wrote reminders to '$filename'\n" if $verbose;
@@ -198,6 +211,12 @@ sub get_model
         elsif ($type eq EmailReminder::BirthdayEvent->get_type()) {
             $store = EmailReminder::BirthdayStore->new();
         } 
+        elsif ($type eq EmailReminder::MonthlyEvent->get_type()) {
+            $store = EmailReminder::MonthlyStore->new();
+        }
+        elsif ($type eq EmailReminder::WeeklyEvent->get_type()) {
+            $store = EmailReminder::WeeklyStore->new();
+        }
         elsif ($type eq EmailReminder::YearlyEvent->get_type()) {
             $store = EmailReminder::YearlyStore->new();
         }
