@@ -149,6 +149,12 @@ sub get_original_date
     return ParseDate($date_string);
 }
 
+sub get_subject
+{
+    my $this = shift;
+    return $this->get_name();
+}
+
 sub get_message_body
 {
     my $this = shift;
@@ -164,8 +170,6 @@ sub get_message_body
     my $event     = defined($occurence) ? "${occurence}$th $name" : $name;
     
     my $message = <<MESSAGEEND;
-Subject: $name
-
 Hi $first_name,
 
 I just want to remind you of the following event $when:
